define((function () { 'use strict';

	console.log('dep');

	var value = 1;

	console.log('main1', value);

}));
